Crate kcode_rust_bins

Crate kcode_rust_bins 

Minimal managed lifecycle for small object-published Rust binaries.

Structs

Error
A bounded displayable crate failure.
File
One complete UTF-8 source file.
Lib
One complete editable managed-binary source snapshot.
ObjectStoreError
Failure returned by a server-supplied object store.
RunRequest
Host request using object IDs rather than inline bytes.
RunResult
Host result after output objects have been saved.
RustBinInput
One guest request after object IDs have been resolved to bytes.
RustBinOutput
One guest response before byte objects are saved.

Constants

DEFAULT_RUN_TIMEOUT
Default maximum running time for one binary call.

Traits

ObjectStore
Policy-blind immutable payload storage supplied by the integrating server.

Functions

create
Creates a minimal Rust 2024 binary and returns its complete source.
docs
Returns the package version and root Documentation.md, migrating when needed.
open
Opens an existing binary, migrating a valid legacy flat repository when needed.
read_input
run
Resolves and executes a locally published binary.
write_output

Type Aliases

ObjectStoreResult
Result