pub fn run(
object_store: &dyn ObjectStore,
binary_object_id: &str,
request: &RunRequest,
) -> Result<RunResult>Expand description
Attempts to execute bytes from any supplied object ID.
pub fn run(
object_store: &dyn ObjectStore,
binary_object_id: &str,
request: &RunRequest,
) -> Result<RunResult>Attempts to execute bytes from any supplied object ID.