Lib

Struct Lib 

pub struct Lib {
    pub files: Vec<File>,
    /* private fields */
}
One complete editable managed-binary source snapshot.

Fields

files: Vec<File>

Every useful UTF-8 source file, canonically sorted after open or write.

Implementations

Source

impl Lib

pub fn write(&mut self) -> Result<()>

Atomically commits files as the complete source if this snapshot is current.

pub fn check(&self) -> Result<()>

Validates and statically builds exactly the current in-memory source.

pub fn publish(&self) -> Result<()>

Validates once and atomically publishes this exact name and version.