pub trait ObjectStore: Send + Sync {
// Required methods
fn load(&self, object_id: &str) -> ObjectStoreResult<Vec<u8>>;
fn save(&self, bytes: &[u8]) -> ObjectStoreResult<String>;
}Expand description
Policy-blind immutable payload storage supplied by the integrating server.
Published executables do not use this store. It is used only to resolve ordered call inputs and save ordered call outputs.
Required Methods
fn load(&self, object_id: &str) -> ObjectStoreResult<Vec<u8>>
fn save(&self, bytes: &[u8]) -> ObjectStoreResult<String>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".