Minimal managed lifecycle for small object-published Rust binaries.
Structs
- Error
- A bounded displayable crate failure.
- File
- One complete UTF-8 source file.
- Lib
- One complete editable managed-binary source snapshot.
- Object
Store Error - Failure returned by a server-supplied object store.
- RunRequest
- Host request using object IDs rather than inline bytes.
- RunResult
- Host result after output objects have been saved.
- Rust
BinInput - One guest request after object IDs have been resolved to bytes.
- Rust
BinOutput - One guest response before byte objects are saved.
Traits
- Object
Store - Policy-blind immutable byte storage supplied by the integrating server.
Functions
- create
- Creates a minimal Rust 2024 binary and returns its complete source.
- docs
- Returns the package version and root
Documentation.md, migrating when needed. - open
- Opens an existing binary, migrating a valid legacy flat repository when needed.
- read_
input - run
- Attempts to execute bytes from any supplied object ID.
- write_
output